@@ -1206,6 +1206,16 @@ DBGP_FUNC(breakpoint_set)
 	if (!CMD_OPTION('t')) {
 		RETURN_RESULT(XG(status), XG(reason), XDEBUG_ERROR_INVALID_ARGS);
 	} else {
+		if (
+			(strcmp(CMD_OPTION('t'), "line") != 0) && 
+			(strcmp(CMD_OPTION('t'), "conditional") != 0) &&
+			(strcmp(CMD_OPTION('t'), "call") != 0) &&
+			(strcmp(CMD_OPTION('t'), "return") != 0) &&
+			(strcmp(CMD_OPTION('t'), "exception") != 0) &&
+			(strcmp(CMD_OPTION('t'), "watch") != 0)
+		) {
+			RETURN_RESULT(XG(status), XG(reason), XDEBUG_ERROR_INVALID_ARGS);
+		}
 		brk_info->type = xdstrdup(CMD_OPTION('t'));
 	}
 
@@ -1786,6 +1796,7 @@ DBGP_FUNC(property_get)
 		options->max_data = old_max_data;
 		RETURN_RESULT(XG(status), XG(reason), XDEBUG_ERROR_PROPERTY_NON_EXISTANT);
 	}
+	options->max_data = old_max_data;
 	XG(active_op_array) = NULL;
 }
 
@@ -1923,6 +1934,7 @@ static int add_variable_contents_node(xdebug_xml_node *node, char *name, int nam
 DBGP_FUNC(property_value)
 {
 	int                        depth = 0;
+	int                        context_nr = 0;
 	function_stack_entry      *fse;
 	int                        old_max_data;
 	xdebug_var_export_options *options = (xdebug_var_export_options*) context->options;
@@ -1935,25 +1947,33 @@ DBGP_FUNC(property_value)
 		depth = strtol(CMD_OPTION('d'), NULL, 10);
 	}
 
-	/* Set the symbol table corresponding with the requested stack depth */
-	if ((fse = xdebug_get_stack_frame(depth TSRMLS_CC))) {
-#if (PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION >= 3) || PHP_MAJOR_VERSION >= 6
-		function_stack_entry *old_fse = xdebug_get_stack_frame(depth - 1 TSRMLS_CC);
+	if (CMD_OPTION('c')) {
+		context_nr = strtol(CMD_OPTION('c'), NULL, 10);
+	}
 
-		if (depth > 0) {
-			XG(active_execute_data) = old_fse->execute_data;
-		} else {
-			XG(active_execute_data) = EG(current_execute_data);
-		}
+	/* Set the symbol table corresponding with the requested stack depth */
+	if (context_nr == 0) { /* locals */
+		if ((fse = xdebug_get_stack_frame(depth TSRMLS_CC))) {
+#if (PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION >= 3) || PHP_MAJOR_VERSION >= 6
+			function_stack_entry *old_fse = xdebug_get_stack_frame(depth - 1 TSRMLS_CC);
+
+			if (depth > 0) {
+				XG(active_execute_data) = old_fse->execute_data;
+			} else {
+				XG(active_execute_data) = EG(current_execute_data);
+			}
 #else
-		XG(active_execute_data) = fse->execute_data;
+			XG(active_execute_data) = fse->execute_data;
 #endif
-		XG(active_symbol_table) = fse->symbol_table;
-		XG(active_op_array)     = fse->op_array;
-		XG(This)                = fse->This;
-		XG(active_fse)          = fse;
-	} else {
-		RETURN_RESULT(XG(status), XG(reason), XDEBUG_ERROR_STACK_DEPTH_INVALID);
+			XG(active_symbol_table) = fse->symbol_table;
+			XG(active_op_array)     = fse->op_array;
+			XG(This)                = fse->This;
+			XG(active_fse)          = fse;
+		} else {
+			RETURN_RESULT(XG(status), XG(reason), XDEBUG_ERROR_STACK_DEPTH_INVALID);
+		}
+	} else { /* superglobals */
+		XG(active_symbol_table) = &EG(symbol_table);
 	}
 
 	if (CMD_OPTION('p')) {
@@ -1976,6 +1996,7 @@ DBGP_FUNC(property_value)
 		RETURN_RESULT(XG(status), XG(reason), XDEBUG_ERROR_PROPERTY_NON_EXISTANT);
 	}
 	options->max_data = old_max_data;
+	XG(active_op_array) = NULL;
 }
 
 static void attach_used_var_with_contents(void *xml, xdebug_hash_element* he, void *options)
